/*
 * libsyncml - A syncml protocol implementation
 * Copyright (C) 2005  Armin Bauer <armin.bauer@opensync.org>
 * Copyright (C) 2008  Michael Bell <michael.bell@opensync.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 *
 */
 
#ifndef _SML_PARSE_INTERNALS_H_
#define _SML_PARSE_INTERNALS_H_

struct SmlParser {
	SmlParserFunctions functions;
	void *parser_userdata;
	SmlMimeType type;
	unsigned int limit;
	SmlManager *manager;
};

struct SmlAssembler {
	SmlAssemblerFunctions functions;
	void *assm_userdata;
	SmlMimeType type;
	GHashTable *options;
	SmlBool empty;

	unsigned int remoteMaxMsgSize;
	unsigned int remoteMaxObjSize;
};

#endif //_SML_PARSE_INTERNALS_H_
